#!/usr/bin/env python
import os
import public
import travis_cron.api


@public.add
def crons(repo):
    """return list of crons"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    url = "%s/repo/%s/crons" % (ENDPOINT, repo.replace("/", "%2F"))
    r = travis_cron.api.request("GET", url)
    crons = []
    for data in r.json()["crons"]:
        cron_id = data["id"]
        branch = data["branch"]["name"]
        interval = data["interval"]
        always = not data["dont_run_if_recent_build_exists"]
        cron = dict(id=cron_id, interval=interval, branch=branch, always=always)
        crons.append(cron)
    return crons


@public.add
def add(repo, branch="master", interval="monthly", always=True):
    """add cron job"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    data = {
        "cron.interval": interval,
        "cron.branch": branch,
        "cron.dont_run_if_recent_build_exists": not always
    }
    url = "%s/repo/%s/branch/%s/cron" % (ENDPOINT, repo.replace("/", "%2F"), branch)
    r = travis_cron.api.request("POST", url, data)
    return r.json()

@public.add
def delete(repo, cron_id):
    """delete cron by id"""
    ENDPOINT = os.getenv("TRAVIS_ENDPOINT", "https://api.travis-ci.org")
    url = "%s/cron/%s" % (ENDPOINT, repo.replace("/", "%2F"), cron_id)
    travis_cron.api.request("DELETE", url)


@public.add
def clear(repo):
    """clear all crons"""
    for cron in crons(repo):
        delete(repo, cron["id"])



#!/usr/bin/env python
"""print travis crons"""
import columnate
import travis_cron
import click

MODULE_NAME = "travis_cron.crons"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
def _cli(repo):
    crons = travis_cron.crons(repo)
    matrix = []
    if crons:
        for cron in crons:
            always = "always" if cron["always"] else ""
            row = [cron["id"], cron["branch"], cron["interval"], always]
            matrix.append(row)
        print(columnate.lists(matrix))


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)



#!/usr/bin/env python
"""delete travis crons by id"""
import travis_cron
import click

MODULE_NAME = "travis_cron.delete"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo cron_id ...' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
@click.argument('cron_id', nargs=-1, required=True)
def _cli(repo, cron_ids):
    for cron_id in cron_ids:
        travis_cron.delete(cron_id)


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)



#!/usr/bin/env python
"""add travis cron"""
import travis_cron
import click

MODULE_NAME = "travis_cron.add"
PROG_NAME = 'python -m %s' % MODULE_NAME
USAGE = 'python -m %s repo [branch] [interval] [always]' % MODULE_NAME


@click.command()
@click.argument('repo', required=True)
@click.argument('branch', default="master", required=False)
@click.argument('interval', default="monthly", required=False)
@click.argument('always', default=True, required=False)
def _cli(repo, branch, interval, always):
    always = True
    if always == ["false", "skip", "no", "0"]:
        always = False
    travis_cron.add(repo, branch, interval, always)


if __name__ == '__main__':
    _cli(prog_name=PROG_NAME)
